@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Sequence, Union
 
+from botocore.response import StreamingBody
+
 from .literals import (
     AlarmTypeType,
     AnomalyDetectorStateValueType,
@@ -28,11 +30,11 @@ from .literals import (
     StatusCodeType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -697,7 +699,7 @@ class GetMetricWidgetImageInputRequestTypeDef(
 GetMetricWidgetImageOutputTypeDef = TypedDict(
     "GetMetricWidgetImageOutputTypeDef",
     {
-        "MetricWidgetImage": bytes,
+        "MetricWidgetImage": StreamingBody,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
